import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:scrobbles/models/settings/settings_activity.dart';
import 'package:scrobbles/models/settings/settings_global.dart';

class Activity {
  Activity({
    // Settings
    required this.activitySettings,
    required this.globalSettings,

    // State
    this.isRunning = false,
  });

  // Settings
  final ActivitySettings activitySettings;
  final GlobalSettings globalSettings;

  // State
  bool isRunning;

  factory Activity.createNull() {
    return Activity(
      // Settings
      activitySettings: ActivitySettings.createDefault(),
      globalSettings: GlobalSettings.createDefault(),
    );
  }

  factory Activity.createNew({
    ActivitySettings? activitySettings,
    GlobalSettings? globalSettings,
  }) {
    final ActivitySettings newActivitySettings =
        activitySettings ?? ActivitySettings.createDefault();
    final GlobalSettings newGlobalSettings = globalSettings ?? GlobalSettings.createDefault();

    return Activity(
      // Settings
      activitySettings: newActivitySettings,
      globalSettings: newGlobalSettings,
      // State
      isRunning: true,
    );
  }

  bool get canBeResumed => true;

  void dump() {
    printlog('');
    printlog('## Current game dump:');
    printlog('');
    printlog('$Activity:');
    printlog('  Settings');
    activitySettings.dump();
    globalSettings.dump();
    printlog('  State');
    printlog('    isRunning: $isRunning');
    printlog('');
  }

  @override
  String toString() {
    return '$Activity(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      // Settings
      'activitySettings': activitySettings.toJson(),
      'globalSettings': globalSettings.toJson(),
      // State
      'isRunning': isRunning,
    };
  }
}
